Documentation
¶
Index ¶
- Variables
- type FieldMapping
- func (*FieldMapping) Descriptor() ([]byte, []int)deprecated
- func (x *FieldMapping) GetPlaceholder() string
- func (x *FieldMapping) GetRequestField() string
- func (*FieldMapping) ProtoMessage()
- func (x *FieldMapping) ProtoReflect() protoreflect.Message
- func (x *FieldMapping) Reset()
- func (x *FieldMapping) String() string
- type Policy
- func (*Policy) Descriptor() ([]byte, []int)deprecated
- func (x *Policy) GetAction() string
- func (x *Policy) GetFieldMappings() []*FieldMapping
- func (x *Policy) GetResource() string
- func (*Policy) ProtoMessage()
- func (x *Policy) ProtoReflect() protoreflect.Message
- func (x *Policy) Reset()
- func (x *Policy) String() string
Constants ¶
This section is empty.
Variables ¶
var (
// optional policy.v1.Policy policy = 50000;
E_Policy = &file_schema_policy_proto_extTypes[0]
)
Extension fields to descriptorpb.MethodOptions.
var File_schema_policy_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type FieldMapping ¶
type FieldMapping struct {
// placeholder is the name used inside the resource template, e.g. "id" for "<id>"
Placeholder string `protobuf:"bytes,1,opt,name=placeholder,proto3" json:"placeholder,omitempty"`
// request_field is the protobuf request field name to extract the value from
RequestField string `protobuf:"bytes,2,opt,name=request_field,json=requestField,proto3" json:"request_field,omitempty"`
// contains filtered or unexported fields
}
func (*FieldMapping) Descriptor
deprecated
func (*FieldMapping) Descriptor() ([]byte, []int)
Deprecated: Use FieldMapping.ProtoReflect.Descriptor instead.
func (*FieldMapping) GetPlaceholder ¶
func (x *FieldMapping) GetPlaceholder() string
func (*FieldMapping) GetRequestField ¶
func (x *FieldMapping) GetRequestField() string
func (*FieldMapping) ProtoMessage ¶
func (*FieldMapping) ProtoMessage()
func (*FieldMapping) ProtoReflect ¶
func (x *FieldMapping) ProtoReflect() protoreflect.Message
func (*FieldMapping) Reset ¶
func (x *FieldMapping) Reset()
func (*FieldMapping) String ¶
func (x *FieldMapping) String() string
type Policy ¶
type Policy struct {
Resource string `protobuf:"bytes,1,opt,name=resource,proto3" json:"resource,omitempty"`
Action string `protobuf:"bytes,2,opt,name=action,proto3" json:"action,omitempty"`
FieldMappings []*FieldMapping `protobuf:"bytes,3,rep,name=field_mappings,json=fieldMappings,proto3" json:"field_mappings,omitempty"`
// contains filtered or unexported fields
}
func (*Policy) Descriptor
deprecated
func (*Policy) GetFieldMappings ¶
func (x *Policy) GetFieldMappings() []*FieldMapping
func (*Policy) GetResource ¶
func (*Policy) ProtoMessage ¶
func (*Policy) ProtoMessage()
func (*Policy) ProtoReflect ¶
func (x *Policy) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.